@@ -19,8 +19,8 @@ def validate_identifier_list(l, enumeration_type):
             error = "%s : code  is not in ['', '01', '02', '04','05', '06', '07', '08']" % d.get('code')
             errors.append(error)
             
-        if not d.get('organization'):
-            error = "%s : organization is required." % (d.get('code'))
+        if not d.get('issuer'):
+            error = "%s : issuer is required." % (d.get('code'))
             errors.append(error)
         
         if not d.get('identifier'):
@@ -31,17 +31,4 @@ def validate_identifier_list(l, enumeration_type):
         if d.get('state') and d.get('state') not in STATES:
             primary_count += 1
     
-    # check that only one taxonomy is marked as primary
-    
-    if primary_count != 1:
-        error = "Exactly 1 taxonomy code must be marked as primary. The primary count is %s." % (primary_count)
-        errors.append(error)
-    
-
-    
-    return errors
-    
-    
-
-
-["", "01", "02", "04","05", "06", "07", "08"]
\ No newline at end of file
+    return errors
\ No newline at end of file
